@@ -1,9 +1,10 @@
 package Dist::Zilla::PluginBundle::RJBS;
-our $VERSION = '0.100650';
+$Dist::Zilla::PluginBundle::RJBS::VERSION = '0.100890';
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
 use Moose::Autobox;
+use Dist::Zilla 2;
 with 'Dist::Zilla::Role::PluginBundle';
 
 
@@ -21,7 +22,7 @@ sub bundle_config {
     name    => $section->{name} . '/@Classic',
     payload => {
       bundle => '@Classic',
-      remove => [ qw(PodVersion) ],
+      remove => [ qw(PodVersion PodCoverageTests) ],
     },
   });
 
@@ -50,6 +51,7 @@ sub bundle_config {
         time_zone => 'America/New_York',
       }
     ],
+    [ MetaConfig   => { } ],
     [ MetaJSON     => { } ],
     [ NextRelease  => { } ],
     [ ($is_task ? 'TaskWeaver' : 'PodWeaver') => { config_plugin => '@RJBS' } ],
@@ -81,7 +83,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 0.100650
+version 0.100890
 
 =head1 DESCRIPTION
 
@@ -90,8 +92,10 @@ This is the plugin bundle that RJBS uses.  It is equivalent to:
   [@Filter]
   bundle = @Classic
   remove = PodVersion
+  remove = PodCoverageTests
 
   [AutoVersion]
+  [MetaConfig]
   [MetaJSON]
   [NextRelease]
   [PodWeaver]
